
FEMAG Tools
===========

Femagtools is a Python-API for FEMAG (https://www.profemag.ch/) offering following features:

* run Femag with a FSL file or model parameters anywhere:
  locally (single and multi-core), remote (ZMQ), HT Condor, Cloud (Amazon AWS, Google Cloud)
* read BCH/BATCH files
* create FSL files from model and calculation templates
* calculate machine characteristics by using analytic machine models
* execute parameter studies and multi-objective optimizations
